@@ -2,10 +2,10 @@
 /*
  * gsf-infile-msvba.c :
  *
- * Copyright (C) 2002 Jody Goldberg (jody@gnome.org)
+ * Copyright (C) 2002-2003 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2.1 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -239,10 +239,9 @@ vba3_dir_read (GsfInfileMSVBA *vba, GError **err)
 	};
 
 	GsfInput *dir;
-	size_t inflated_size;
+	int inflated_size;
 	guint8 *inflated;
-	guint8 const *data;
-	unsigned offset, size, name_len, i, j;
+	unsigned offset, name_len, i, j;
 	char *name;
 
 	dir = gsf_infile_child_by_name (vba->source, "dir");
@@ -544,7 +543,7 @@ GSF_CLASS (GsfInfileMSVBA, gsf_infile_msvba,
 	   gsf_infile_msvba_class_init, gsf_infile_msvba_init,
 	   GSF_INFILE_TYPE)
 
-GsfInfile *
+GsfInfileMSVBA *
 gsf_infile_msvba_new (GsfInfile *source, GError **err)
 {
 	GsfInfileMSVBA *vba;
@@ -558,7 +557,7 @@ gsf_infile_msvba_new (GsfInfile *source, GError **err)
 
 	/* find the name offset pairs */
 	if (vba56_dir_read (vba, err) || vba3_dir_read (vba, err))
-		return GSF_INFILE (vba);
+		return vba;
 
 	if (err != NULL && *err == NULL) {
 		*err = g_error_new (gsf_input_error (), 0,
